@@ -1,6 +1,6 @@
 package MARC::Moose::Lint::Processor;
 # ABSTRACT: Processor to lint iso2709 file
-$MARC::Moose::Lint::Processor::VERSION = '1.0.16';
+$MARC::Moose::Lint::Processor::VERSION = '1.0.17';
 use Moose;
 use Modern::Perl;
 use MARC::Moose::Reader::File::Iso2709;
@@ -12,39 +12,45 @@ extends 'AnyEvent::Processor';
 has lint => (is => 'rw', isa => 'MARC::Moose::Lint::Checker');
 
 
-has file => (is => 'rw' );
+has file => (
+    is => 'ro',
+    isa => 'Str',
+    trigger => sub {
+        my ($self, $file) = @_;
+        $self->reader( MARC::Moose::Reader::File::Iso2709->new(
+            file => $file ) );
+        $self->writer_ok( MARC::Moose::Writer->new(
+            formater => MARC::Moose::Formater::Iso2709->new(),
+            fh => IO::File->new("$file.ok", ">:encoding(utf8)")
+        ) );
+        $self->writer_bad( MARC::Moose::Writer->new(
+            formater => MARC::Moose::Formater::Iso2709->new(),
+            fh => IO::File->new("$file.bad", ">:encoding(utf8)")
+        ) );
+        $self->fh_log( IO::File->new("$file.log", ">:encoding(utf8)") );
+    },
+);
 
 
 has cleaner => (is => 'rw', isa => 'MARC::Moose::Formater');
 
 
-has reader => (is => 'rw');
-has writer_ok => (is => 'rw');
+has reader => (is => 'rw', isa => 'MARC::Moose::Reader' );
+
+
+has writer_ok => (is => 'rw', isa => 'MARC::Moose::Writer' );
+
+
+has writer_bad => (is => 'rw', isa => 'MARC::Moose::Writer' );
+
+
+has fh_log => (is => 'rw', isa => 'IO::File');
+
 has count_ok => (is => 'rw', isa => 'Int', default => 0);
-has writer_bad => (is => 'rw');
 has count_bad => (is => 'rw', isa => 'Int', default => 0);
-has fh_log => (is => 'rw');
 
 
 
-sub BUILD {
-    my $self = shift;
-
-    my $file = $self->file;
-    $self->reader( MARC::Moose::Reader::File::Iso2709->new(
-        file => $file ) );
-    $self->writer_ok( MARC::Moose::Writer->new(
-        formater => MARC::Moose::Formater::Iso2709->new(),
-        fh => IO::File->new("$file.ok", ">:encoding(utf8)")
-    ) );
-    $self->writer_bad( MARC::Moose::Writer->new(
-        formater => MARC::Moose::Formater::Iso2709->new(),
-        fh => IO::File->new("$file.bad", ">:encoding(utf8)")
-    ) );
-    $self->fh_log( IO::File->new("$file.log", ">:encoding(utf8)") );
-};
-
-
 sub process {
     my $self = shift;
 
@@ -73,11 +79,13 @@ sub start_message {
     say "Start linting biblio records";
 }
 
+
 sub process_message {
     my $self = shift;
     say $self->count, " - OK ", $self->count_ok, " - BAD ", $self->count_bad;
 }
 
+
 sub end_message {
     my $self = shift;
     my $file = $self->file;
@@ -103,7 +111,7 @@ MARC::Moose::Lint::Processor - Processor to lint iso2709 file
 
 =head1 VERSION
 
-version 1.0.16
+version 1.0.17
 
 =head1 ATTRIBUTES
 
@@ -113,7 +121,13 @@ A L<MARC::Moose::Lint::Checker> to be used to validate biblio record.
 
 =head2 file
 
-The name of the ISO2709 file containing biblio records to control.
+The name of an ISO2709 file containing biblio records to control. When the
+processor object is created with this attribute, other attributes are
+automatically constructed: C<reader> as L<MARC::Moose::Reader::File::Iso2709>
+object reading the file, C<writer_ok> and C<writer_bad> as
+L<MARC::Moose::Writer> object with an ISO2709 formater writing to files named
+'file.ok' and 'file.bad', and C<fh_log> as a L<IO::File>, writing a text file
+named 'file.log'.
 
 =head2 cleaner
 
@@ -121,6 +135,23 @@ A L<MARC::Moose::Formater> which transform a L<MARC::Moose::Record> into
 another L<MARC::Moose::Record>. Using a cleaner, it's possible to clean biblio
 records before validating them.
 
+=head2 reader
+
+A L<MARC::Moose::Reader> object from which biblio records are read.
+
+=head2 writer_ok
+
+A L<MARC::Moose::Writer> object in which valid biblio records are written.
+
+=head2 writer_bad
+
+A L<MARC::Moose::Writer> object in which unvalid biblio records are written.
+
+=head2 writer_bad
+
+A L<IO::File> file handle which is used to write unvalid biblio records with
+generated warnings.
+
 =head1 SYNOPSYS
 
  package PeterCleaner;
@@ -141,7 +172,7 @@ records before validating them.
  package Main;
  
  my $processor = MARC::Moose::Lint::Processor->new(
-     lint => MARC::Moose::Lint::Checker->new( file => 'unimarc.rules',
+     lint => MARC::Moose::Lint::Checker::RulesFile->new( file => 'unimarc.rules',
      file => 'biblio.mrc',
      cleaner => PeterCleaner->new(),
      verbose => 1,
@@ -155,6 +186,24 @@ C<biblio.mrc.bad> containing biblios violating the rules, and (3)
 C<biblio.mrc.log> containing a textual representation of biblio records
 violating the rules + a description of violated rules.
 
+A more specific construction is also possible:
+
+ my $processor = MARC::Moose::Lint::Processor->new(
+     lint => MARC::Moose::Lint::Checker::RulesFile->new( file => 'unimarc.rules',
+     reader => MARC::Moose::Reader::File::Marcxml->new('biblio.xml'),
+     writer_ok => MARC::Moose::Writer->new(
+         formater => MARC::Moose::Formater::Marcxml->new(),
+         fh => IO::File->new('ok.xml', '>:encoding(utf8')
+     ),
+     writer_bad => MARC::Moose::Writer->new(
+         formater => MARC::Moose::Formater::Marcxml->new(),
+         fh => IO::File->new('bad.xml', '>:encoding(utf8')
+     ),
+     fh_log => IO::File->new('warnings.log', '>:encoding(utf8'),
+     verbose => 1,
+ };
+ $processor->run();
+
 =head1 SEE ALSO
 
 =over 4
